#[repr(u32)]pub enum EntryState {
Incomplete = 1,
Reachable = 2,
Stale = 3,
Delay = 4,
Probe = 5,
Static = 6,
Unreachable = 7,
}Variants
Incomplete = 1
Reachability is in the process of being confirmed for a newly created, non-static entry.
Reachable = 2
Positive reachability has been confirmed; the path to the neighbor is functioning properly.
Stale = 3
Reachability is considered unknown.
Occurs in one of two ways:
- Too much time has elapsed since the last positive reachability confirmation was received.
- Received a reachability confirmation from a neighbor with a different MAC address than the one cached.
Delay = 4
A packet was recently sent while reachability was considered unknown.
This state is an optimization that gives non-Neighbor-Discovery related protocols time to confirm reachability after the last confirmation of reachability has expired due to lack of recent traffic.
Probe = 5
A reachability confirmation is actively sought by periodically retransmitting reachability probes until a reachability confirmation is received, or until the maximum number of probes has been sent.
Static = 6
Static entries are explicitly added with [Controller.AddEntry].
They do not expire and are not deleted until explicitly removed with
[Controller.RemoveEntry]. A static entry may be converted into a
dynamic entry with [Controller.ProbeEntry], however, at which
point it may be subject to expiry and deletion.
Unreachable = 7
Negative reachability has been confirmed; the path to the neighbor may not be functioning properly. A reachability confirmation was not received after transmitting the maximum number of reachability probes.
Implementations
Sourceimpl EntryState
impl EntryState
pub fn from_primitive(prim: u32) -> Option<EntryState>
pub const fn into_primitive(self) -> u32